MAX_CONCURRENT      = 3
CHAPTERS_PER_MINUTE = 20
BASE_IMG_URL        = "https://img2.imglib.info"
API_BASE_URL        = "https://api2.mangalib.me/api/"
TELEGRAPH_CREDS     = dict(
    short_name  ='Damir',
    author_name ='Создано mangagraph',
    author_url  ='https://github.com/damirTAG/mangagraph'
)

HEADERS = {
    'Authorization' :   'Bearer eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiJ9.eyJhdWQiOiIxIiwianR'
                        'pIjoiNWE5YmI5MDVmNjlmNzJkYTkxN2Q5YjY4OTU3ZWI2ODI0MDFkYjUyYjFhNzhjMDk0ZDg3MWExN2Qy'
                        'MmFjYjk2ZTg5YWM4ZjJmN2Q2YjBkNTMiLCJpYXQiOjE3NDE4MTI2NjEuODMzNTU0LCJuYmYiOjE3NDE4M'
                        'TI2NjEuODMzNTU2LCJleHAiOjE3NDQ0OTEwNjEuODI5NzY4LCJzdWIiOiI3MDExNTkwIiwic2NvcGVzIj'
                        'pbXX0.teJSwDcP0jp2yuuJLM5kFH3f89qVHOEOvKws70gvc6oo9Gd-dBLt8XSMipL-5ypHCFFTb5qfj9i'
                        '2xvquUpA618JMDyP31wwfZvaa3h8vVvdeEeWjf98xMpjq8ngMGioSJiWc4WipFmF7sXDpWPvKN-6ECEG8V'
                        'oYA0bd7FhxdGYeJS5GrK2tcdMxHoCtIW8HrMdo0LTYtqtz3c5bq_FnrRljqrdxU2GyxTI7QxRk81X5xZK'
                        'XBkvSEmm1l3DEJPkIP22KjegOC5jQzh_sv3GN4yHWMr7m2py5_A2Gwgm7hbH-q9a_Aw8CB-mripbxSqug'
                        '0Z6yT4kcWxd0AePLztGdTQx8Gd9oPqP9twDZIJnwguyQGOBQ-DHRjYrl0XSAn89OQIbcvQtveSk7vY0_8'
                        'l3COUGeRkNBBg2BT-C0jYOb7SVb_tn59VAmm5a2Z9ZdCyXhzfqVoe9yw1I0DlefUpxeFSyfo9G7ktxTep'
                        'sWY0NMW9S9I_PFg7WLlXX_0jwtbAcuQ6AA1QRiLW-QvAR5cYnbq7jkreF-o_Ja8XxIjRNKuemDtj9feTt'
                        'shGWxnfMYPJcfRFaVxpGlon6nNL9qVFJmB8UrqGeFUqwjlZ0PFAsvVxN459il1YOysYObG6OhW1IcKWtK'
                        'Px5lkXjbH5UqcDqRYAIxPT1uVWU2npmgGE6gq_9U',
    'User-Agent'    :   'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/134.0.0.0 Safari/537.36'
}